CartEntity class

Constructors

CartEntity({required String? appId, String? title, String? description, String? checkoutText, String? shopId, BackgroundEntity? itemImageBackground, BackgroundEntity? itemDetailBackground, ActionEntity? checkoutAction, ActionEntity? backToShopAction, ActionEntity? openProductAction, StorageConditionsEntity? conditions})

Properties

appId → String?
final
backToShopAction → ActionEntity?
final
checkoutAction → ActionEntity?
final
checkoutText → String?
final
conditions → StorageConditionsEntity?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
itemDetailBackground → BackgroundEntity?
final
itemImageBackground → BackgroundEntity?
final
openProductAction → ActionEntity?
final
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shopId → String?
final
title → String?
final

Methods

copyWith({String? documentID, String? appId, String? title, String? description, String? checkoutText, String? shopId, BackgroundEntity? itemImageBackground, BackgroundEntity? itemDetailBackground, ActionEntity? checkoutAction, ActionEntity? backToShopAction, ActionEntity? openProductAction, StorageConditionsEntity? conditions}) → CartEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → CartEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → CartEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → CartEntity?