OrderEntity class

Constructors

OrderEntity({required String? appId, String? customerId, String? name, String? email, String? shipStreet1, String? shipStreet2, String? shipCity, String? shipState, String? postcode, String? country, bool? invoiceSame, String? invoiceStreet1, String? invoiceStreet2, String? invoiceCity, String? invoiceState, String? invoicePostcode, String? invoiceCountry, List<OrderItemEntity>? products, double? totalPrice, String? currency, String? paymentReference, String? shipmentReference, String? deliveryReference, String? paymentNote, String? shipmentNote, String? deliveryNote, int? status, String? timeStamp})

Properties

appId → String?
final
country → String?
final
currency → String?
final
customerId → String?
final
deliveryNote → String?
final
deliveryReference → String?
final
email → String?
final
hashCode → int
The hash code for this object.
no setterinherited
invoiceCity → String?
final
invoiceCountry → String?
final
invoicePostcode → String?
final
invoiceSame → bool?
final
invoiceState → String?
final
invoiceStreet1 → String?
final
invoiceStreet2 → String?
final
name → String?
final
paymentNote → String?
final
paymentReference → String?
final
postcode → String?
final
products → List<OrderItemEntity>?
final
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shipCity → String?
final
shipmentNote → String?
final
shipmentReference → String?
final
shipState → String?
final
shipStreet1 → String?
final
shipStreet2 → String?
final
status → int?
final
timeStamp → String?
final
totalPrice → double?
final

Methods

copyWith({String? documentID, String? appId, String? customerId, String? name, String? email, String? shipStreet1, String? shipStreet2, String? shipCity, String? shipState, String? postcode, String? country, bool? invoiceSame, String? invoiceStreet1, String? invoiceStreet2, String? invoiceCity, String? invoiceState, String? invoicePostcode, String? invoiceCountry, List<OrderItemEntity>? products, double? totalPrice, String? currency, String? paymentReference, String? shipmentReference, String? deliveryReference, String? paymentNote, String? shipmentNote, String? deliveryNote, int? status, String? timeStamp}) → OrderEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → OrderEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → OrderEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → OrderEntity?