OrderOverviewModel class

Constructors

OrderOverviewModel({required String documentID, required String appId, String? description, ShopModel? shop, BackgroundModel? itemImageBackground, BackgroundModel? itemDetailBackground, StorageConditionsModel? conditions})

Properties

appId ↔ String
getter/setter pairoverride
conditions ↔ StorageConditionsModel?
getter/setter pair
description ↔ String?
getter/setter pair
documentID ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
itemDetailBackground ↔ BackgroundModel?
getter/setter pair
itemImageBackground ↔ BackgroundModel?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shop ↔ ShopModel?
getter/setter pair

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? appId, String? description, ShopModel? shop, BackgroundModel? itemImageBackground, BackgroundModel? itemDetailBackground, StorageConditionsModel? conditions}) → OrderOverviewModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → OrderOverviewEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(String documentID, OrderOverviewEntity? entity) → Future<OrderOverviewModel?>
fromEntityPlus(String documentID, OrderOverviewEntity? entity, {String? appId}) → Future<OrderOverviewModel?>

Constants

id → const String
packageName → const String