ShopFrontEntity class

Constructors

ShopFrontEntity({required String? appId, String? title, String? description, String? shopId, double? size, double? cardElevation, double? cardAxisSpacing, BackgroundEntity? itemCardBackground, RgbEntity? addToCartColor, int? scrollDirection, ActionEntity? buyAction, ActionEntity? openProductAction, EdgeInsetsGeometryEntity? padding, StorageConditionsEntity? conditions})

Properties

addToCartColor → RgbEntity?
final
appId → String?
final
buyAction → ActionEntity?
final
cardAxisSpacing → double?
final
cardElevation → double?
final
conditions → StorageConditionsEntity?
final
description → String?
final
hashCode → int
The hash code for this object.
no setterinherited
itemCardBackground → BackgroundEntity?
final
openProductAction → ActionEntity?
final
padding → EdgeInsetsGeometryEntity?
final
props → List<Object?>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection → int?
final
shopId → String?
final
size → double?
final
title → String?
final

Methods

copyWith({String? documentID, String? appId, String? title, String? description, String? shopId, double? size, double? cardElevation, double? cardAxisSpacing, BackgroundEntity? itemCardBackground, RgbEntity? addToCartColor, int? scrollDirection, ActionEntity? buyAction, ActionEntity? openProductAction, EdgeInsetsGeometryEntity? padding, StorageConditionsEntity? conditions}) → ShopFrontEntity
enrichedDocument(Map<String, Object?> theDocument) → Future<Map<String, Object?>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
switchAppId({required String newAppId}) → ShopFrontEntity
override
toDocument() → Map<String, Object?>
override
toJsonString() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromJsonString(String json, {Map<String, String>? newDocumentIds}) → ShopFrontEntity?
fromMap(Object? o, {Map<String, String>? newDocumentIds}) → ShopFrontEntity?