ShopFrontModel class

Constructors

ShopFrontModel({required String documentID, required String appId, String? title, String? description, ShopModel? shop, double? size, double? cardElevation, double? cardAxisSpacing, BackgroundModel? itemCardBackground, RgbModel? addToCartColor, ScrollDirection? scrollDirection, ActionModel? buyAction, ActionModel? openProductAction, EdgeInsetsGeometryModel? padding, StorageConditionsModel? conditions})

Properties

addToCartColor ↔ RgbModel?
getter/setter pair
appId ↔ String
getter/setter pairoverride
buyAction ↔ ActionModel?
getter/setter pair
cardAxisSpacing ↔ double?
getter/setter pair
cardElevation ↔ double?
getter/setter pair
conditions ↔ StorageConditionsModel?
getter/setter pair
description ↔ String?
getter/setter pair
documentID ↔ String
getter/setter pairoverride
hashCode → int
The hash code for this object.
no setteroverride
itemCardBackground ↔ BackgroundModel?
getter/setter pair
openProductAction ↔ ActionModel?
getter/setter pair
padding ↔ EdgeInsetsGeometryModel?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollDirection ↔ ScrollDirection?
getter/setter pair
shop ↔ ShopModel?
getter/setter pair
size ↔ double?
getter/setter pair
title ↔ String?
getter/setter pair

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith({String? documentID, String? appId, String? title, String? description, ShopModel? shop, double? size, double? cardElevation, double? cardAxisSpacing, BackgroundModel? itemCardBackground, RgbModel? addToCartColor, ScrollDirection? scrollDirection, ActionModel? buyAction, ActionModel? openProductAction, EdgeInsetsGeometryModel? padding, StorageConditionsModel? conditions}) → ShopFrontModel
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → ShopFrontEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override

Static Methods

fromEntity(String documentID, ShopFrontEntity? entity) → Future<ShopFrontModel?>
fromEntityPlus(String documentID, ShopFrontEntity? entity, {String? appId}) → Future<ShopFrontModel?>

Constants

id → const String
packageName → const String