ActionModel class abstract

Constructors

ActionModel(AppModel app, {DisplayConditionsModel? conditions, String? actionType})

Properties

actionType → String?
final
app → AppModel
final
conditions ↔ DisplayConditionsModel?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
copyWith(AppModel newApp) → ActionModel
describe() → String
hasAccess(BuildContext context) → Future<bool>
message() → String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → ActionEntity
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromEntity(ActionEntity? entity) → Future<ActionModel?>
fromEntityPlus(ActionEntity? entity, {String? appId}) → Future<ActionModel?>