WorkflowActionModel class

Inheritance

Constructors

WorkflowActionModel(AppModel app, {WorkflowModel? workflow, DisplayConditionsModel? conditions})

Properties

actionType → String?
finalinherited
app → AppModel
finalinherited
conditions ↔ DisplayConditionsModel?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
workflow → WorkflowModel?
final

Methods

collectReferences({String? appId}) → Future<List<ModelReference>>
override
copyWith(AppModel newApp) → ActionModel
override
describe() → String
override
hasAccess(BuildContext context) → Future<bool>
inherited
message() → String
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toEntity({String? appId}) → WorkflowActionEntity
override
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromEntity(WorkflowActionEntity? entity) → Future<WorkflowActionModel?>
override
fromEntityPlus(WorkflowActionEntity? entity, {String? appId}) → Future<WorkflowActionModel?>
override